==> ideaIC-182.4323.18-sources.jar: org/jetbrains/plugins/github/extensions/InteractiveGithubHttpAuthDataProvider.kt <==
// Copyright 2000-2018 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package org.jetbrains.plugins.github.extensions

import com.intellij.openapi.application.ModalityState
import com.intellij.openapi.project.Project
import com.intellij.util.AuthData
import git4idea.DialogManager
import git4idea.remote.InteractiveGitHttpAuthDataProvider
import org.jetbrains.annotations.CalledInAwt
import org.jetbrains.plugins.github.authentication.GithubAuthenticationManager
import org.jetbrains.plugins.github.authentication.accounts.GithubAccount
import org.jetbrains.plugins.github.authentication.ui.GithubChooseAccountDialog
import org.jetbrains.plugins.github.util.GithubUtil
import javax.swing.JComponent

internal class InteractiveGithubHttpAuthDataProvider(private val project: Project,
                                                     private val potentialAccounts: Collection<GithubAccount>,
                                                     private val authenticationManager: GithubAuthenticationManager) : InteractiveGitHttpAuthDataProvider {

  @CalledInAwt
  override fun getAuthData(parentComponent: JComponent?): AuthData? {
    val dialog = GithubChooseAccountDialog(project,
                                           parentComponent,
                                           potentialAccounts,
                                           null,
                                           false,
                                           true,
                                           "Choose GitHub Account",
                                           "Log In")
    DialogManager.show(dialog)
    if (!dialog.isOK) return null
    val account = dialog.account
    val modalityStateSupplier = { parentComponent?.let(ModalityState::stateForComponent) ?: ModalityState.any() }
    val token = authenticationManager.getOrRequestTokenForAccount(account,
                                                                  parentComponent = parentComponent,
                                                                  modalityStateSupplier = modalityStateSupplier)
                ?: return null
    if (dialog.setDefault) authenticationManager.setDefaultAccount(project, account)
    return AuthData(GithubUtil.GIT_AUTH_PASSWORD_SUBSTITUTE, token)
  }
}

==> ideaIC-183.2407.10-sources.jar: org/jetbrains/plugins/github/extensions/InteractiveGithubHttpAuthDataProvider.kt <==
// Copyright 2000-2018 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package org.jetbrains.plugins.github.extensions

import com.intellij.openapi.application.ModalityState
import com.intellij.openapi.application.invokeAndWaitIfNeed
import com.intellij.openapi.project.Project
import com.intellij.util.AuthData
import git4idea.DialogManager
import git4idea.remote.InteractiveGitHttpAuthDataProvider
import org.jetbrains.annotations.CalledInAwt
import org.jetbrains.plugins.github.authentication.GithubAuthenticationManager
import org.jetbrains.plugins.github.authentication.accounts.GithubAccount
import org.jetbrains.plugins.github.authentication.ui.GithubChooseAccountDialog
import org.jetbrains.plugins.github.util.GithubUtil
import java.awt.Component

internal class InteractiveGithubHttpAuthDataProvider(private val project: Project,
                                                     private val potentialAccounts: Collection<GithubAccount>,
                                                     private val authenticationManager: GithubAuthenticationManager) : InteractiveGitHttpAuthDataProvider {

  @CalledInAwt
  override fun getAuthData(parentComponent: Component?): AuthData? {
    val dialog = GithubChooseAccountDialog(project,
                                           parentComponent,
                                           potentialAccounts,
                                           null,
                                           false,
                                           true,
                                           "Choose GitHub Account",
                                           "Log In")
    DialogManager.show(dialog)
    if (!dialog.isOK) return null
    val account = dialog.account
    val token = invokeAndWaitIfNeed(parentComponent?.let(ModalityState::stateForComponent) ?: ModalityState.any()) {
      authenticationManager.getOrRequestTokenForAccount(account, project, parentComponent)
    } ?: return null
    if (dialog.setDefault) authenticationManager.setDefaultAccount(project, account)
    return AuthData(GithubUtil.GIT_AUTH_PASSWORD_SUBSTITUTE, token)
  }
}
